#
# spec file for package glycin-loaders
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without jxl

Name:           glycin-loaders
Version:        1.0.1
Release:        1.1
Summary:        Sandboxed image rendering
License:        LGPL-2.1-or-later OR MPL-2.0
URL:            https://gitlab.gnome.org/sophie-h/glycin
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst

BuildRequires:  cargo-packaging
BuildRequires:  clang
BuildRequires:  git
BuildRequires:  meson
BuildRequires:  pkgconfig
%if %{with jxl}
BuildRequires:  (pkgconfig(libjxl) >= 0.8.2 with pkgconfig(libjxl) < 0.11.0)
%endif
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gtk4) >= 4.12.0
BuildRequires:  pkgconfig(libheif) >= 1.17.4
BuildRequires:  pkgconfig(libseccomp) >= 2.5.0
BuildRequires:  pkgconfig(libxml-2.0)

%description
Sandboxed and extendable image decoding.

%prep
%autosetup -p1 -a1

%build
export RUSTFLAGS="%{build_rustflags}"
%meson \
	-Dloaders=glycin-heif,glycin-image-rs,glycin-svg%[%{with jxl}?",glycin-jxl":""] \
	%{nil}
%meson_build

%install
export RUSTFLAGS="%{build_rustflags}"
%meson_install

%files
%dir %{_libexecdir}/glycin-loaders
%dir %{_libexecdir}/glycin-loaders/1+
%{_libexecdir}/glycin-loaders/1+/glycin-heif
%{_libexecdir}/glycin-loaders/1+/glycin-image-rs
%{_libexecdir}/glycin-loaders/1+/glycin-svg
%dir %{_datadir}/glycin-loaders
%dir %{_datadir}/glycin-loaders/1+
%dir %{_datadir}/glycin-loaders/1+/conf.d
%{_datadir}/glycin-loaders/1+/conf.d/glycin-heif.conf
%{_datadir}/glycin-loaders/1+/conf.d/glycin-image-rs.conf
%{_datadir}/glycin-loaders/1+/conf.d/glycin-svg.conf
%if %{with jxl}
%{_libexecdir}/glycin-loaders/1+/glycin-jxl
%{_datadir}/glycin-loaders/1+/conf.d/glycin-jxl.conf
%endif

%changelog
* Thu Apr  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.1:
  + loaders/utils: Register SIGSYS handler as early as possible for
    better debugging for unallowed syscalls.
  + sandbox: Allow membarrier, open, stat syscalls.
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.0:
  + glycin: Change to stable crate version.
  + svg: Change to stable rsvg version.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.rc:
  + glycin: Allow fstat syscall.
  + glycin: Treat files detected as XML as SVG if they have .svg
    file ending.
  + jxl: Allow libjxl 0.10 as well.
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.beta.2:
  + api: Rename a few functions.
  + api: Use memfds for larger metadata like Exif or ICC profiles.
  + glycin/glycin-utils: Drop all uses of anyhow.
  + glycin/glycin-utils: Use thiserror to define types.
  + glycin: Check image width and height are not zero.
  + loaders/image-rs: Disable memory limits since we have our own.
  + loaders: Use new error utils tracking code location.
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.beta.1:
  + Update to zbus 4.0.
  + glycin: Use more fine-tuned memory limits using max 80%%
    available memory.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.beta:
  + Consitently use Loader instead of Decoder terminology in code.
  + glycin: Add seccomp filter based on allow list for bwrap
    sandboxes.
  + jxl: Support Exif.
- Changes from version 1.0.alpha:
  + Replace async-std with other crates
  + Use a new D-Bus API version 1+ allowing for backward compatible
    extendability.
* Thu Nov 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Run service with new obs-service-cargo, drop cargo_config as
  source and clean up spec and. Cargo_audit and cargo_config are
  now part of the cargo_vendor tarball/service, but in this case,
  since the sourcedir in _service is called glycin, we need to keep
  the manual set cargo_audit in _service to clear validation.
* Tue Nov 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.2:
  + GIF/APNG/WEBP: Assume frame length of 100ms if provided frame
    length is zero or invalid.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.1:
  + Distribute correct Cargo.lock for glycin-loaders tarballs.
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to full cargo packaging, add service and setup vendoring.
* Thu Sep 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.0:
  + Update dependencies.
* Sun Sep  3 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 0.1.rc:
  + No visible changes for the user.
* Wed Aug 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.beta.4:
  + Relicense under MPL-2.0 OR LGPL-2.1-or-later
  + Add symlinks for license files in crates
  + Add cairo dependency for svg loader
  + HEIC: Fix filetype detection in config
  + tests:
  - Add HEIC tests
  - Add option to skip image formats in tests
  - Run required install before tests (can be disabled)
- Add pkgconfig(cairo) BuildRequires, new dependency.
- Pass explicit
  loaders=glycin-heif,glycin-image-rs,glycin-jxl,glycin-svg to
  meson, ensure we build all the loaders.
- Update License tag following upstreams relicense.
* Tue Aug 22 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 0.1.beta.3.
